<?php

/*
 * This file is part of the AuthStack project.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 */

namespace AuthStack\SP\Errors;

/**
 * Class InvalidStatusException
 * @package AuthStack\SP\Errors
 *
 *          Thrown when SAML Status isn't success
 */
class InvalidStatusException extends \Exception
{}